package be.iminds.ilabt.jfed.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.crypto.Cipher;
import java.security.NoSuchAlgorithmException;

/**
 * HighStrengthCipherUtil
 *
 * detect "Disabling high-strength ciphers: cipher strengths apparently limited by JCE policy"
 */
public class HighStrengthCipherUtil {
    private static final Logger LOG = LoggerFactory.getLogger(HighStrengthCipherUtil.class);

    private HighStrengthCipherUtil() {}

    public static boolean hasHighStrengthCipher() {
        boolean test1;
        boolean test2;
        try {
            test1 = Cipher.getMaxAllowedKeyLength("RC5") >= 256;
            test2 = Cipher.getMaxAllowedKeyLength("AES") > 128;
        } catch (NoSuchAlgorithmException e) {
            LOG.warn("Error checking HighStrengthCipher", e);
            return false;
        }

        return test1 && test2;
    }

    public static String getHighStrengthCipherDebugString() {
        String res = "";
        try {
            res += "RC5.len=" + Cipher.getMaxAllowedKeyLength("RC5");
            res += " AES.len=" + Cipher.getMaxAllowedKeyLength("AES");
        } catch (NoSuchAlgorithmException e) {
            LOG.warn("Error checking HighStrengthCipher", e);
            return res+" Error checking HighStrengthCipher: "+e.getMessage();
        }

        return res;
    }
}
